==> diffusion-6.10.6-1-py3-none-any.whl: diffusion/datatypes/timeseries/types.py <==
#  Copyright (c) 2022 - 2024 DiffusionData Ltd., All Rights Reserved.
#
#  Use is subject to licence terms.
#
#  NOTICE: All information contained herein is, and remains the
#  property of DiffusionData. The intellectual and technical
#  concepts contained herein are proprietary to DiffusionData and
#  may be covered by U.S. and Foreign Patents, patents in process, and
#  are protected by trade secret or copyright law.
import typing
from pydantic import StrictBool

from diffusion.datatypes.complex import ComplexDataTypesClasses, ComplexDataTypes
from diffusion.datatypes.primitives import (
    PrimitiveDataTypesClasses,
    PrimitiveDataTypes,
    RawDataTypes,
)

TimeSeriesValueTypeClasses = typing.Union[
    PrimitiveDataTypesClasses, ComplexDataTypesClasses
]
"""
Possible typing.Type values for a Time Series Value
"""

TimeSeriesValueType = typing.Union[PrimitiveDataTypes, ComplexDataTypes]
"""
Possible types for a Time Series Value
"""

RawComplexDataTypes = typing.Union[
    typing.List[typing.Any], typing.Dict[typing.Any, typing.Any]
]
"""
Types that could be JSON
"""

TimeSeriesValueTypeOrRaw = typing.Optional[typing.Union[
    TimeSeriesValueType,
    RawDataTypes,
    RawComplexDataTypes,
    StrictBool
]]
"""
Time Series Value Type parameter
"""

VT_argtype = typing.TypeVar("VT_argtype", bound=TimeSeriesValueTypeOrRaw)
"""
Time Series Value Type parameter (TypeVar)
"""

VT = typing.TypeVar("VT", bound=TimeSeriesValueType)
"""
Possible types for a Time Series Value (TypeVar)
"""

VT_covariant = typing.TypeVar("VT_covariant", bound=TimeSeriesValueType, covariant=True)
"""
Possible types for a Time Series Value (TypeVar, covariant)
"""

VT_other = typing.TypeVar("VT_other", bound=TimeSeriesValueType)
"""
Possible types for a Time Series Value conversion target
"""

==> diffusion-6.11.2-1-py3-none-any.whl: diffusion/datatypes/timeseries/types.py <==
#  Copyright (c) 2022 - 2024 DiffusionData Ltd., All Rights Reserved.
#
#  Use is subject to licence terms.
#
#  NOTICE: All information contained herein is, and remains the
#  property of DiffusionData. The intellectual and technical
#  concepts contained herein are proprietary to DiffusionData and
#  may be covered by U.S. and Foreign Patents, patents in process, and
#  are protected by trade secret or copyright law.
import typing

from diffusion.datatypes.complex import ComplexDataTypesClasses, ComplexDataTypes
from diffusion.datatypes.primitives import (
    PrimitiveDataTypesClasses,
    PrimitiveDataTypes,
)
from diffusion.datatypes.foundation.ibytesdatatype import IBytes
from diffusion.datatypes.raw import RawDataTypes

TimeSeriesValueTypeClasses = typing.Union[
    PrimitiveDataTypesClasses, ComplexDataTypesClasses
]
"""
Possible typing.Type values for a Time Series Value
"""

TimeSeriesValueType_Diffusion = typing.Union[PrimitiveDataTypes, ComplexDataTypes]
"""
Possible implementation types for a Time Series Value
"""

RawComplexDataTypes = typing.Union[
    typing.List[typing.Any], typing.Dict[typing.Any, typing.Any]
]
"""
Types that could be JSON
"""

TimeSeriesValueType = typing.Union[TimeSeriesValueType_Diffusion, IBytes]
TimeSeriesValueTypeOrRaw = typing.Union[
    TimeSeriesValueType, RawDataTypes
]
"""
Time Series Value Type parameter
"""
VT_argtype = typing.TypeVar("VT_argtype", bound=typing.Union[bytes, TimeSeriesValueTypeOrRaw])
"""
Time Series Value Type parameter (TypeVar)
"""

VT = typing.TypeVar("VT", bound=TimeSeriesValueType)
"""
Possible types for a Time Series Value (TypeVar)
"""

VT_other = typing.TypeVar("VT_other", bound=TimeSeriesValueType)
"""
Possible types for a Time Series Value conversion target
"""
